// ---------------------
// USER SETTINGS
// ---------------------
// After changing settings:
// 1. Save this file
// 2. In Studio One, open the External Devices List in the Console
// 3. Find your iCON control surface, press the arrow to open the menu
// 4. Select 'Reset'


const Settings = {
    
    // ----------------------------------------------
    // The first scene that's selected on startup
    // ----------------------------------------------
    // Chose from "track", "pan", "send", "cue", "plugin"
    startScene: "track",

    // ------------------------------------
    // Set if the startup scene is focused
    // ------------------------------------
    // false:   The scene is not focused on startup
    // true:    The scene will be focused on startup
    startFocused: false,

    // -------------------------------------------------------------------------------------
    // Change where 0dB shows on the controller's VU level meters
    // NOTE: This setting is for tracks only. The Master channel VU Meter always uses "full"
    // -------------------------------------------------------------------------------------
    // "green"  = Meter is rescaled so that:
    //            0dB is the highest value that will light the top green segment.
    //            Levels over 0dB and up to +8dB will be in the orange range.
    //            Levels over +8dB will cause the red overload light to come on.
    // "full"   = Meter is rescaled so that 0dB is the highest value that will light the top orange segement.
    //            Levels over 0dB will cause the red overload light to come on.
    //            The top of the green zone is -12dB.
    // "none"   = Default Studio One scaling - designed for the Faderport controllers. 
    //            These levels don't make much sense when displayed on the P1-M's meter:
    //            The lowest green segment is always lit.
    //            The orange zone starts at -7.3dB.  
    //            0dB is somewhere in the third orange segment
    //            The red overload lights up over +6.6dB
    changeMeter0dBPosition: "full",

    // ----------------------------     
    // Show Scene Info On Startup
    // ----------------------------
    // true:  On startup, the scene info is shown.
    // false: On startup, the scene info is not shown.
    showSceneInfo : true,

    // --------------------------------
    // DAW Follows Controller 
    // --------------------------------
    // true:    When selecting a track on the controller, the Studio One console
    //          is scrolled to bring that track into view.
    // false:   The Studio One console is kept where it is. 
    //          The selected track may not be visible.
    dawFollowsController: true,

    // --------------------------------
    // Nano Follows DAW 
    // --------------------------------
    // true:    When selecting a track on the Studio One console
    //          the P1-Nano is banked to show the selected track.
    // false:   The P1-Nano will not be automatically banked.
    //          You can use the 'Locate' button to bring the selected 
    //          track into view.
    nanoFollowsDAW: true,

    // ---------------------------------
    // Show Leading Zeros in Time Code 
    // ---------------------------------
    // true:    The time code will show leading 0s.
    //          e.g. [000.00.04.19]
    // false:   The time code will NOT show leading 0s.
    //          e.g. [  0. 0. 4.19]
    timeCodeLeadingZeros: false,

    // -----------------------------------------------------
    // Changes how long labels are truncated to 7 characters. 
    // Labels of 7 characters or fewer are not processed. 
    // Labels starting with numbers or +/- are not processed.
    // Examples below show how the label "Backing Vox 2" will appear.  
    // -----------------------------------------------------
    // "simple":        Only the first 7 characters are shown. e.g. "Backing".
    // "includeEnd":    The first 4 characters from the start, followed
    //                  by the last 3 characters. e.g. "Backox2"
    // "allWords":      Tries to show a bit of each word. e.g. "BacVox2"
    labelTruncation: "allWords",
    
    // -----------------------------------------------------
    // Disables the plugin control mode.
    // -----------------------------------------------------
    // true:    The controller will no longer control plugins
    // false:   The controller will control plugins when the plugin scene
    //          is active and the plugin editor is open.
    disablePluginControl: false,

    // -----------------------------------------------------
    // Disables the instrument control mode.
    // -----------------------------------------------------
    // true:    The controller will no longer control virtual instruments
    // false:   The controller will control virtual instruments when the 
    //          instruments scene is active and the instrument editor is open.
    disableInstrumentControl: false,

    // -----------------------------------------------------
    // Controls the behaviour of the P1-Nano selection mode
    // -----------------------------------------------------
    // true:    The select mode will remain on until you turn it off
    // false:   The select mode will be turned off after you make a selection 
    keepNanoSelectModeOnAfterSelection: false,
};
